Interned

Struct Interned 

pub struct Interned<I>
where I: Interner,
{ /* private fields */ }
An interned string key parameterized by Interner type I.

With GlobalInterner, this is 4 bytes and Copy. With NoInterner, this is a pointer and Clone only.

Serde support serializes as the string value and deserializes via interning.

Implementations

Source

impl<I> Interned<I>
where I: Interner,

pub fn intern(s: &str) -> Interned<I>

Intern a string, returning a new Interned<I>.

pub fn resolve(&self) -> &str

Resolve this interned key back to its original string.