pub struct Interned<I>where
I: Interner,{ /* private fields */ }Expand description
An interned string key parameterized by Interner type I.
With GlobalInterner, this is 4 bytes and Copy.
With NoInterner, this is a pointer and Clone only.
Serde support serializes as the string value and deserializes via interning.
Implementations